=== modified file 'client/drizzle.cc'
--- client/drizzle.cc	2009-07-18 22:54:35 +0000
+++ client/drizzle.cc	2009-07-20 00:15:20 +0000
@@ -1240,11 +1240,8 @@
 
   if (status.batch && !status.line_buff)
   {
-    try
-    {
-      status.line_buff= new LineBuffer(opt_max_input_line+512, stdin);
-    } 
-    catch (...)
+    status.line_buff= new(std::nothrow) LineBuffer(opt_max_input_line+512, stdin);
+    if (status.line_buff == NULL)
     {
       free_defaults(defaults_argv);
       my_end(0);
@@ -1697,17 +1694,14 @@
   case 'e':
     status.batch= 1;
     status.add_to_history= 0;
-    try
-    {
-      if (!status.line_buff)
-	status.line_buff= new LineBuffer(opt_max_input_line+512,NULL);
-      status.line_buff->add_string(argument);
-    } 
-    catch (...)
+    if (status.line_buff == NULL)
+      status.line_buff= new(std::nothrow) LineBuffer(opt_max_input_line+512,NULL);
+    if (status.line_buff == NULL)
     {
       my_end(0);
       exit(1);
     }
+    status.line_buff->addString(argument);
     break;
   case 'o':
     if (argument == disabled_my_option)
@@ -1859,32 +1853,18 @@
     if (!interactive)
     {
       if (status.line_buff)
-	line= status.line_buff->readline();
+        line= status.line_buff->readline();
       else
-	line= 0;
+        line= 0;
 
-      if (line)
+      line_number++;
+      if (show_progress_size > 0)
       {
-	/*
-	  Skip UTF8 Byte Order Marker (BOM) 0xEFBBBF.
-	  Editors like "notepad" put this marker in
-	  the very beginning of a text file when
-	  you save the file using "Unicode UTF-8" format.
-	*/
-	if (!line_number &&
-	    (unsigned char) line[0] == 0xEF &&
-	    (unsigned char) line[1] == 0xBB &&
-	    (unsigned char) line[2] == 0xBF)
-	  line+= 3;
-	line_number++;
-	if (show_progress_size > 0)
-	{
-	  if ((line_number % show_progress_size) == 0)
-	    fprintf(stderr, _("Processing line: %"PRIu32"\n"), line_number);
-	}
-	if (!glob_buffer->empty())
-	  status.query_start_line=line_number;
+        if ((line_number % show_progress_size) == 0)
+          fprintf(stderr, _("Processing line: %"PRIu32"\n"), line_number);
       }
+      if (!glob_buffer->empty())
+        status.query_start_line=line_number;
     }
     else
     {
@@ -3699,11 +3679,8 @@
     return put_info(buff, INFO_ERROR, 0 ,0);
   }
 
-  try
-  {
-    line_buff= new LineBuffer(opt_max_input_line+512,sql_file);
-  }
-  catch (...)
+  line_buff= new(std::nothrow) LineBuffer(opt_max_input_line+512,sql_file);
+  if (line_buff == NULL)
   {
     fclose(sql_file);
     return put_info("Can't initialize LineBuffer", INFO_ERROR, 0, 0);

=== modified file 'client/linebuffer.cc'
--- client/linebuffer.cc	2009-07-18 22:51:44 +0000
+++ client/linebuffer.cc	2009-07-20 00:15:20 +0000
@@ -19,24 +19,21 @@
 #include <mysys/my_sys.h>
 #include "client/linebuffer.h"
 
-#include <stdexcept>
+#include <vector>
 
 using namespace std;
 
 LineBuffer::LineBuffer(uint32_t my_max_size,FILE *my_file)
-{
-  file= my_file;
-  max_size= my_max_size;
-  line= new char[max_size];
-  eof= false;
-}
-
-LineBuffer::~LineBuffer()
-{
-  delete line;
-}
-
-void LineBuffer::add_string(const char *str)
+  :
+    file(my_file),
+    line(),
+    max_size(my_max_size),
+    eof(false)
+{
+  line.reserve(max_size);
+}
+
+void LineBuffer::addString(const string &str)
 {
   buffer << str << endl;
 }
@@ -47,20 +44,22 @@
 
   if (file && !eof)
   {
-    if ((read_count=my_read(fileno(file),(unsigned char *) line,max_size-1,MYF(MY_WME))))
+    if ((read_count=my_read(fileno(file),
+                            (unsigned char *) (&line[0]),
+                            max_size-1,MYF(MY_WME))))
     {
-      line[read_count+1]= 0;
-      buffer << line;
+      line[read_count+1]= '\0';
+      buffer << &line[0];
     }
     else
       eof= true;
   }
 
-  buffer.getline(line,max_size);
+  buffer.getline(&line[0],max_size);
 
   if (buffer.eof())
     return 0;
   else
-    return line;
+    return &line[0];
 }
 

=== modified file 'client/linebuffer.h'
--- client/linebuffer.h	2009-07-18 22:51:44 +0000
+++ client/linebuffer.h	2009-07-20 00:15:20 +0000
@@ -16,20 +16,21 @@
 #ifndef CLIENT_LINEBUFFER_H
 #define CLIENT_LINEBUFFER_H
 
+#include <vector>
+
 class LineBuffer
 {
 public:
   LineBuffer(uint32_t max_size,FILE *file);
-  ~LineBuffer();
 
-  void add_string(const char *argument);
+  void addString(const std::string &argument);
   char *readline();
 private:
   FILE *file;
   std::stringstream buffer;
-  char *line;
+  std::vector<char> line;
   uint32_t max_size;
-  uint32_t eof;
+  bool eof;
 };
 
 #endif /* CLIENT_LINEBUFFER_H */

